@@ -1,28 +1,15 @@
-/*
- * Batch encryption functions.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * Copyright © 2016-2018 The TokTok team.
+ * Copyright © 2013-2016 Tox Developers.
  */
 
 /*
- * Copyright © 2016-2018 The TokTok team.
- * Copyright © 2013-2016 Tox Developers.
- *
- * This file is part of Tox, the free peer to peer instant messenger.
- *
- * Tox is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * Tox is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Tox.  If not, see <http://www.gnu.org/licenses/>.
+ * Batch encryption functions.
  */
-#ifndef TOXENCRYPTSAVE_H
-#define TOXENCRYPTSAVE_H
+#ifndef C_TOXCORE_TOXENCRYPTSAVE_TOXENCRYPTSAVE_H
+#define C_TOXCORE_TOXENCRYPTSAVE_TOXENCRYPTSAVE_H
+
+//!TOKSTYLE-
 
 #ifdef __cplusplus
 extern "C" {
@@ -375,4 +362,11 @@ bool tox_is_data_encrypted(const uint8_t *data);
 }
 #endif
 
-#endif
+typedef TOX_ERR_KEY_DERIVATION Tox_Err_Key_Derivation;
+typedef TOX_ERR_ENCRYPTION Tox_Err_Encryption;
+typedef TOX_ERR_DECRYPTION Tox_Err_Decryption;
+typedef TOX_ERR_GET_SALT Tox_Err_Get_Salt;
+
+//!TOKSTYLE+
+
+#endif // C_TOXCORE_TOXENCRYPTSAVE_TOXENCRYPTSAVE_H
